/*
  ******************************************************************************
  * @file    apt32f172_ifc.c
  * @author  APT AE Team
  * @version V1.12
  * @date    2019/03/08
  ******************************************************************************
  *THIS SOFTWARE WHICH IS FOR ILLUSTRATIVE PURPOSES ONLY WHICH PROVIDES 
  *CUSTOMER WITH CODING INFORMATION REGARDING THEIR PRODUCTS.
  *APT CHIP SHALL NOT BE HELD RESPONSIBILITY ADN LIABILITY FOR ANY DIRECT, 
  *INDIRECT DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF 
  *SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION 
  *CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.AND APT CHIP RESERVES 
  *THE RIGHT TO MAKE CHANGES IN THE SOFTWARE WITHOUT NOTIFICATION
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "apt32f172_ifc.h"

/* define --------------------------------------------------------------------*/
#define	_FlashData_BUFSIZE		10
unsigned char FlashDataArry[_FlashData_BUFSIZE];
unsigned char DataBuffer[_FlashData_BUFSIZE];   //Read out data buffer	
/* externs--------------------------------------------------------------------*/
/*************************************************************
//Enable or Disable IFC Interrupt when Operate FlashData 
//EntryParameter:FlashAdd、DataSize、*BufArry
//ReturnValue:NONE
*************************************************************/
//DataSize 一定是4的倍数
void ProgramData(unsigned int FlashAdd,unsigned int DataSize,unsigned char *BufArry)
{
	int i,DataBuffer;
	
	for(i=0;i<((DataSize+3)/4);i++)   //sizeof structure
	{
		SetUserKey;
		WrProgramAdd(FlashAdd);
		DataBuffer=*BufArry+(*(BufArry+1)<<8)+(*(BufArry+2)<<16)+(*(BufArry+3)<<24);
		WrProgramData(DataBuffer);
		EnNormalProgram;
		StartProgram;
		while((GetCRStatus)!=0);
		BufArry  +=4;
		FlashAdd +=4;
	}
}
/*************************************************************
// ReadFlashData fuction return Data arry save in Flash
//EntryParameter:RdStartAdd、DataLength、*DataArryPoint
//ReturnValue:NONE
*************************************************************/
//DataLength 一定是4的倍数
void ReadDataArry(unsigned int RdStartAdd,unsigned int DataLength,unsigned char *DataArryPoint)
{
	unsigned int i,Buffer;
	
	for(i=0;i<((DataLength+3)/4);i++)
	{
		Buffer=*(volatile unsigned int *)RdStartAdd;
		*DataArryPoint=Buffer;
		*(DataArryPoint+1)=Buffer>>8;
		*(DataArryPoint+2)=Buffer>>16;
		*(DataArryPoint+3)=Buffer>>24;
		RdStartAdd +=4;
		DataArryPoint +=4;
	}
}
/*************************************************************
//ProgramOneWord fuction use to write four data into chip's Rom
//EntryParameter:ProgramAdd、WrData
//ProgramAdd：0x00000000~0x00007c00;0x10000000~0x10000C00
//WrDat：4BYTE
//ReturnValue:NONE
*************************************************************/   
void ProgramOneWord(unsigned int ProgramAdd,unsigned int WrData)
{
	volatile unsigned int Result=0;
	do
	{
		SetUserKey;
		WrProgramAdd(ProgramAdd);
		WrProgramData(WrData);
		EnNormalProgram;
		StartProgram;
		while((GetCRStatus)!=0);
		Result=*(volatile unsigned int *)ProgramAdd;
	}
	while(Result!= WrData);
}
/*************************************************************
//ReadFlashWord fuction return Data save in Flash
//EntryParameter:NONE
//ReturnValue:NONE
*************************************************************/  
unsigned int ReadOneWord(unsigned int RdAdd)
{
	unsigned int DataBuffer=*(volatile unsigned int *)RdAdd;
	return DataBuffer;
}

/*************************************************************
//ChipErase fuction
//EntryParameter:NONE
//ReturnValue:NONE
*************************************************************/
void ChipErase(void)
{
	SetUserKey;
	EnChipErase;
	StartErase;
	while((GetCRStatus)!=0);
	while((GetIFCRawStatus & Undefine_INT)==Undefine_INT)ClrUndefineErro;
}

/*************************************************************
//PageErase fuction
//EntryParameter:XROM_PageAdd_Erase:
//XROM_PageAdd_Erase:PROM_PageAdd0_Erase~PROM_PageAdd35_Erase
//DROM_PageAdd0_Erase~DROM_PageAdd3_Erase
//ReturnValue:NONE
*************************************************************/
void PageErase(IFC_ROMSELETED_TypeDef XROM_PageAdd_Erase)
{
	SetUserKey;
	EnPageErase;
	WrProgramAdd(XROM_PageAdd_Erase);
	StartErase;
	while((GetCRStatus)!=0);
	while((GetIFCRawStatus & Add_INT)==Add_INT)ClrAddErro;;
}

/*************************************************************/
// IFC CMR Set
//EntryParameter:IFC_CMR
//IFC_CMR:Program_Byte/Page_Erase/Chip_Erase/Option_Erase/HDP_1K_EN
//HDP_2K_EN/HDP_4K_EN/HDP_FULL_EN/RDP_EN/DEBUGP_EN/UseOpion_EN
//ReturnValue:NONE
/*************************************************************/  
void IFC_CMR_Set(IFC_CMR_TypeDef IFC_CMR)
{
	SetUserKey;
	SetIFCCommand(IFC_CMR);
	StartProgram;
	while((GetCRStatus)!=0);
}

/*************************************************************/
//IFC DATA Write example
//EntryParameter:FlashDataArry[_FlashData_BUFSIZE]
//start address=0x10000000
//ReturnValue:NONE
/*************************************************************/
void FlashData_Write(void)
{
	unsigned int i;
	for(i=0;i<_FlashData_BUFSIZE;i++)
	{
		//FlashDataArry[i]=i;
		DataBuffer[i]=0;
	}
	EnIFCClk;
	PageErase(DROM_PageAdd0_Erase);					
	ProgramData(0x10000000,_FlashData_BUFSIZE,&FlashDataArry[0]);
	ReadDataArry(0x10000000,_FlashData_BUFSIZE,&DataBuffer[0]);
	for(i=0;i<_FlashData_BUFSIZE;i++)
	{
		while(DataBuffer[i]!=FlashDataArry[i]);
	}
	DisIFCClk;
}

/*************************************************************/
//IFC DATA Read example
//EntryParameter:None
//start address=0x10000000
//ReturnValue:DataBuffer
/*************************************************************/
void FlashData_Read(void)
{
	EnIFCClk;
	ReadDataArry(0x10000000,_FlashData_BUFSIZE,&DataBuffer[0]);
	DisIFCClk;
}

/*************************************************************/
//IFC Interrupt erase
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
U32_T get_user_option(void)
{
	U32_T opt;
	IFC -> CEDR = IFC_CLKEN;   			//enable IFC clock	
	CSP_IFC_SET_KR(IFC, USER_KEY); 	// Write Key
	CSP_IFC_SET_CMR(IFC, HIDM3); 	// 
	opt =  *((volatile unsigned int *)(0x00080084));
	return opt;
}

/*************************************************************/
//IFC Interrupt erase
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void erase_user_option(void)
{	
	IFC -> CEDR = IFC_CLKEN;   //enable IFC clock
	IFC->SRR = IFC_SWRST; // soft reset
	CSP_IFC_SET_KR(IFC, USER_KEY); // Write Key
	CSP_IFC_SET_CMR(IFC, HIDM1|IF0_ERASE); // IF0 Erase
	CSP_IFC_SET_CR(IFC, START); // Start Erase
	while ( CSP_IFC_GET_CR(IFC) != 0x0 ); // Wait for operation done
}

/*************************************************************/
//IFC Interrupt erase
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void set_user_option(U32_T opt)
{
	U16_T i =0,j=0;
	IFC -> CEDR = IFC_CLKEN;   						//enable IFC clock
	IFC->SRR = IFC_SWRST; 							// soft reset		
	erase_user_option();
	for(i=0;i<1000;i++)
	{
		for(j=0;j<1000;j++)
		{
			j=j+0;
		}
	}
	CSP_IFC_SET_KR(IFC, USER_KEY);      			// Write Key
    CSP_IFC_SET_CMR(IFC, HIDM1|USER_OPTION);    	// Program
    CSP_IFC_SET_DR(IFC, opt);    					// Program data
    CSP_IFC_SET_CR(IFC, START);         			// Start Program
    while ( CSP_IFC_GET_CR(IFC) != 0x0 );  			// Wait for operation done
}

/*************************************************************
//Enable or Disable IFC Interrupt when Operate FlashData 
//EntryParameter:IFC_INT_x
//IFC_INT_x:End_INT、Port_INT、Undefine_INT、Add_INT、OverWrite_INT
//ReturnValue:NONE
*************************************************************/
void IFC_interrupt_CMD(FunctionalStatus NewState ,IFC_INT_TypeDef IFC_INT_x)
{
	if(NewState != DISABLE)
	{
		IFC->ICR =IFC->ICR|IFC_INT_x;
	}
	else 
	{
		IFC->ICR =IFC->ICR & (~IFC_INT_x);
	}
}

/*************************************************************/
//IFC Interrupt enable
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void IFC_Int_Enable(void)
{
    IFC->ICLR=0XF000;					//CLAER IFC INT status
	INTC_ISER_WRITE(IFC_INT);    
}

/*************************************************************/
//IFC Interrupt enable
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void IFC_Int_Disable(void)
{
    INTC_ICER_WRITE(IFC_INT);    
}
/******************* (C) COPYRIGHT 2018 APT Chip *****END OF FILE****/