/*
  ******************************************************************************
  * @file    apt32f172_gpio.h
  * @author  APT AE Team
  * @version V1.12
  * @date    2018/03/08
  ******************************************************************************
  *THIS SOFTWARE WHICH IS FOR ILLUSTRATIVE PURPOSES ONLY WHICH PROVIDES 
  *CUSTOMER WITH CODING INFORMATION REGARDING THEIR PRODUCTS.
  *APT CHIP SHALL NOT BE HELD RESPONSIBILITY ADN LIABILITY FOR ANY DIRECT, 
  *INDIRECT DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF 
  *SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION 
  *CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.AND APT CHIP RESERVES 
  *THE RIGHT TO MAKE CHANGES IN THE SOFTWARE WITHOUT NOTIFICATION
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/ 
#ifndef _apt32f172_gpio_H
#define _apt32f172_gpio_H
/* Includes ------------------------------------------------------------------*/
#include "apt32f172.h"
/******************************************************************************
************************ GPIO Registers Definition *************************
******************************************************************************/

#define nop      asm ("nop")

#define SetPA0(n)   (GPIOA0->SODR = (1ul<<n))
#define ClrPA0(n)   (GPIOA0->CODR = (1ul<<n))

#define SetPB0(n)   (GPIOB0->SODR = (1ul<<n))
#define ClrPB0(n)   (GPIOB0->CODR = (1ul<<n))

#define PA0in(n)    (((GPIOA0->PSDR)>>n) & 1ul)
#define PB0in(n)    (((GPIOB0->PSDR)>>n) & 1ul)


#define CSP_GPIO_SET_CONLR(cm,val) ((cm)->CONLR = val)
#define CSP_GPIO_GET_CONLR(cm)     ((cm)->CONLR)

#define CSP_GPIO_SET_CONHR(cm,val) ((cm)->CONHR = val)
#define CSP_GPIO_GET_CONHR(cm)     ((cm)->CONHR)

#define CSP_GPIO_SET_WODR(cm,val) ((cm)->WODR = val)
#define CSP_GPIO_SET_SODR(cm,val) ((cm)->SODR = val)
#define CSP_GPIO_SET_CODR(cm,val) ((cm)->CODR = val)
#define CSP_GPIO_GET_PSDR(cm)     ((cm)->PSDR)

#define CSP_GPIO_SET_PUDR(cm,val) ((cm)->PUDR = val)
#define CSP_GPIO_GET_PUDR(cm)     ((cm)->PUDR)

#define CSP_GPIO_SET_DSCR(cm,val) ((cm)->DSCR = val)
#define CSP_GPIO_GET_DSCR(cm)     ((cm)->DSCR)

#define CSP_GPIO_SET_OMCR(cm,val) ((cm)->OMCR = val)
#define CSP_GPIO_GET_OMCR(cm)     ((cm)->OMCR)

#define CSP_GPIO_SET_IECR(cm,val) ((cm)->IECR = val)
#define CSP_GPIO_GET_IECR(cm)     ((cm)->IECR)

#define CSP_GPIO_SET_IGRPL(cm,val) ((cm)->IGRPL = val)
#define CSP_GPIO_GET_IGRPL(cm)     ((cm)->IGRPL)

#define CSP_GPIO_SET_IGRPH(cm,val) ((cm)->IGRPH = val)
#define CSP_GPIO_GET_IGRPH(cm)     ((cm)->IGRPH)


#define GPIO_RESET_VALUE  (0x00000000)
//--------------------------------------------------------------------------------
//-----------------------------GPIO  value enum define--------------------------
//--------------------------------------------------------------------------------
/**
  * @brief  GPIO pin numbner
  */
typedef enum
{
  PIN_0    = 0,  /*!< Pin 0 selected */
  PIN_1    = 4,  /*!< Pin 1 selected */
  PIN_2    = 8,  /*!< Pin 2 selected */
  PIN_3    = 12,   /*!< Pin 3 selected */
  PIN_4    = 16,  /*!< Pin 4 selected */
  PIN_5    = 20,  /*!< Pin 5 selected */
  PIN_6    = 24,  /*!< Pin 6 selected */
  PIN_7    = 28,  /*!< Pin 7 selected */
  PIN_8    = 0,  /*!< Pin 8 selected */
  PIN_9    = 4,  /*!< Pin 9 selected */
  PIN_10   = 8,  /*!< Pin 10 selected */
  PIN_11   = 12,   /*!< Pin 11 selected */
  PIN_12   = 16,  /*!< Pin 12 selected */
  PIN_13   = 20,  /*!< Pin 13 selected */
  PIN_14   = 24,  /*!< Pin 14 selected */
  PIN_15   = 28,  /*!< Pin 15 selected */
}GPIO_Pin_TypeDef;
/**
  * @brief  GPIO  high/low register
  */
typedef enum
{
    LowByte = 0,
    HighByte = 1,
}GPIO_byte_TypeDef;
/**
  * @brief  GPIO  IO status
  */
typedef enum
{
    Intput = 1,
    Output = 0,
}GPIO_Dir_TypeDef;
/**
  * @brief  GPIO  IO mode
  */
typedef enum
{
    IO_PULL_HIGH_LOW = 0,
    IO_DRV_STRENGHT =1,
    IO_OPEN_DRAIN =2,
    IO_INT_EN =3,
	IO_INT_ENSet=4,
	IO_INT_DISSet=5,
    IO_INT_GROUPL =6,
	IO_INT_GROUPH =7,
    PUDR = 0,                       //pull high or low
    DSCR =1,                        //drive strenth
    OMCR =2,                        //open drain
    IECR =3,                        //int
	IEER =4,                        //int
	IEDR =5,                        //int
    IGRPL =6,                        //GPIO INT GROUP
	IGRPH =7,                        //GPIO INT GROUP
}GPIO_Mode_TypeDef;
/**
  * @brief  GPIO  IO Group
  */
typedef enum
{
    PA0 = 0,
	PA1 = 1,
    PB0 = 2,
    PC0 = 3,
    PD0 = 4,    
}GPIO_Group_TypeDef;
/**
  * @brief  GPIO  exi number
  */
typedef enum
{
    EXI0 = 0,
    EXI1 = 1,
    EXI2 = 2,
    EXI3 = 3,
    EXI4 = 4,
    EXI5 = 5,
    EXI6 = 6,
    EXI7 = 7,
    EXI8 = 8,
    EXI9 = 9,
    EXI10 = 10,
    EXI11 = 11,
    EXI12 = 12,
    EXI13 = 13,
	EXI14 = 14,
    EXI15 = 15,
}GPIO_EXI_TypeDef;


/******************************************************************************
************************** Exported functions ************************
******************************************************************************/
extern void GPIO_DeInit(void);
extern void GPIO_Init(CSP_GPIO_T *GPIOx,U8_T PinNum,GPIO_Dir_TypeDef Dir);
extern void GPIO_Init2(CSP_GPIO_T *GPIOx,GPIO_byte_TypeDef byte,uint32_t val);
extern void GPIO_MODE_Init(CSP_GPIO_T *GPIOx,GPIO_Mode_TypeDef IO_MODE,uint32_t val);
extern void GPIO_PullHigh_Init(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_PullLow_Init(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_PullHighLow_DIS(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_OpenDrain_EN(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_OpenDrain_DIS(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_DriveStrength_EN(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_DriveStrength_DIS(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_IntGroup_Set(GPIO_Group_TypeDef IO_MODE);
extern void GPIO_IntGroup_Set_1(CSP_GPIO_T *GPIOx,U32_T bit);
extern void GPIOA0_EXI_Init(GPIO_EXI_TypeDef EXI_IO);
extern void GPIOA1_EXI_Init(GPIO_EXI_TypeDef EXI_IO);
extern void GPIOB0_EXI_Init(GPIO_EXI_TypeDef EXI_IO);
extern void GPIOC0_EXI_Init(GPIO_EXI_TypeDef EXI_IO);
extern void GPIO_EXI_EN(CSP_GPIO_T *GPIOx,GPIO_EXI_TypeDef EXI_IO);
extern void GPIO_EXI_ENSet(CSP_GPIO_T *GPIOx,GPIO_EXI_TypeDef EXI_IO);
extern void GPIO_EXI_DISSet(CSP_GPIO_T *GPIOx,GPIO_EXI_TypeDef EXI_IO);
extern void GPIO_Write_High(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_Write_Low(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIO_Set_Value(CSP_GPIO_T *GPIOx,U8_T bitposi,U8_T bitval);
extern void GPIO_Reverse(CSP_GPIO_T *GPIOx,U8_T bit);
extern uint8_t GPIO_Read_Status(CSP_GPIO_T *GPIOx,U8_T bit);
extern uint8_t GPIO_Read_Output(CSP_GPIO_T *GPIOx,U8_T bit);
extern void GPIOA00_Set_ResetPin();

#endif   /**< apt32f172_gpio_H */
/******************* (C) COPYRIGHT 2018 APT Chip *****END OF FILE****/
