/*
  ******************************************************************************
  * @file    apt32f172_tc2_st16.h
  * @author  APT AE Team
  * @version V1.12
  * @date    2018/03/08
  ******************************************************************************
  *THIS SOFTWARE WHICH IS FOR ILLUSTRATIVE PURPOSES ONLY WHICH PROVIDES 
  *CUSTOMER WITH CODING INFORMATION REGARDING THEIR PRODUCTS.
  *APT CHIP SHALL NOT BE HELD RESPONSIBILITY ADN LIABILITY FOR ANY DIRECT, 
  *INDIRECT DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF 
  *SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION 
  *CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.AND APT CHIP RESERVES 
  *THE RIGHT TO MAKE CHANGES IN THE SOFTWARE WITHOUT NOTIFICATION
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/ 
#ifndef _apt32f172_tc2_st16_H
#define _apt32f172_tc2_st16_H

/* Includes ------------------------------------------------------------------*/
#include "apt32f172.h"
 
/******************************************************************************
************************** ST16 Registers Definition ****************************
******************************************************************************/
 /** @addtogroup ST16 Registers RST  Value
  * @{
  */
  #define 	STC_IDR_RST          	(0x0041000Aul)      /**< IDR reset value      */
  #define 	STC_CEDR_RST		 	(0x00000000ul)		/**< CEDR reset value     */	
  #define 	STC_RSSR_RST			(0x00000000ul)		/**< RSSR reset value     */	
  #define 	STC_IMSCR_RST			(0x00000000ul)		/**< IMSCR reset value    */	
  #define 	STC_RISR_RST			(0x00000000ul)		/**< RISR reset value     */	
  #define 	STC_MISR_RST			(0x00000000ul)		/**< MISR reset value     */	
  #define 	STC_ICR_RST				(0x00000000ul)		/**< ICR reset value      */	
  #define 	STC_SR_RST				(0x00000000ul)		/**< SR reset value       */	
  #define 	STC_MR_RST				(0x00000000ul)		/**< MR reset value       */	
  #define	STC_CNTBR_RST			(0x00000000ul)		/**< CNTBR reset value    */
  #define 	STC_CNTR_RST			(0x00000000ul)		/**< CNTR reset value     */
  #define 	STC_CDR_RST				(0x00000000ul)		/**< CDR reset value      */
  #define 	STC_PCNTR_RST			(0x00000000ul)		/**< PCNTR reset value    */
  #define 	STC_CRR_RST				(0x00000000ul)		/**< CRR reset value      */
  #define 	STC_CMR_RST				(0x00000000ul)		/**< CMR reset value      */
  #define 	STC_CIMSCR_RST			(0x00000000ul)		/**< CIMSCR reset value   */	
  #define 	STC_CRISR_RST			(0x00000000ul)		/**< CRISR reset value    */	
  #define 	STC_CMISR_RST			(0x00000000ul)		/**< CMISR reset value    */
  #define 	STC_CICR_RST			(0x00000000ul)		/**< CICR reset value     */	
  #define 	STC_CAPSR_RST			(0x00000000ul)		/**< CAPSR reset value    */
  #define 	STC_CC0R_RST			(0x00000000ul)		/**< CC0R reset value     */
  #define 	STC_CC1R_RST			(0x00000000ul)		/**< CC1R reset value     */
/**
  * @brief  STC16 MINT  
  */  
typedef enum
{
	STC16_IO_CAP0	=	0,
	STC16_IO_CAP1	=	1
}ST16_IO_MODE_TypeDef;  

/**
  * @brief  STC16 MINT  
  */  
typedef enum
{
	ST16_STARTI   =     (0x01ul << 0),      /**< ST Start Interrupt       */
	ST16_STOPI    =     (0x01ul << 1),      /**< ST Stop Interrupt        */
	ST16_PENDI    =     (0x01ul << 2)      	/**< ST PEND Interrupt        */
}STC16_MINT_TypeDef;

/**
  * @brief  STC16 CINT  
  */  
typedef enum
{
	ST16_CC0RI   =      (0x01ul << 0),      /**< ST channel 0 R interrupt */
	ST16_CC1RI   =      (0x01ul << 1),      /**< ST channel 1 R interrupt */
	ST16_Match0  =      (0x01ul << 0),      /**< ST channel Match0 R interrupt */
	ST16_Match1  =      (0x01ul << 1),      /**< ST channel Match1 R interrupt */
	ST16_CC0FI   =      (0x01ul << 8),      /**< ST channel 0 F interrupt */
	ST16_CC1FI   =      (0x01ul << 9)       /**< ST channel 1 F interrupt */
}STC16_CINT_TypeDef;
 
/**
  * @brief  STC16 Count mode  
  */  
typedef enum
{
	STC16_Count_mode_Continue	=	(0x00ul << 24),
	STC16_Count_mode_Oneshot	=	(0x01ul << 24)
}STC16_Count_mode_TypeDef; 

/**
  * @brief  STC16 Count mode  
  */  
typedef enum
{
	STC16_Count_STOPTYPE_AutoLoad		=	(0x00ul << 9),
	STC16_Count_STOPTYPE_StopConmand	=	(0x01ul << 9)
}STC16_Count_STOPTYPE_TypeDef; 

/**
  * @brief  STC16 COSR Capture Triggle SET
  */  
typedef enum
{
	STC16_C0SR_CaptureRise		=	(0x01ul<<16) ,
	STC16_C0SR_CaptureFall		=	(0x02ul<<16) ,
	STC16_C0SR_CaptureRiseFall	=	(0x03ul<<16) 
}STC16_C0SR_TypeDef;

/**
  * @brief  STC16 C1SR Capture Triggle SET
  */  
typedef enum
{
	STC16_C1SR_CaptureRise		=	(0x01ul << 18),
	STC16_C1SR_CaptureFall		=	(0x02ul << 18),
	STC16_C1SR_CaptureRiseFall	=	(0x03ul << 18)
}STC16_C1SR_TypeDef;

/**
  * @brief  STC16 CM0 mode set
  */  
typedef enum
{
	STC16_CM0_Mode_Capture	=	0x01ul,
	STC16_CM0_Mode_Match	=	0x00ul
}STC16_CM0_Mode_TypeDef;

/**
  * @brief  STC16 CM1 mode set
  */  
typedef enum
{
	STC16_CM1_Mode_Capture	=	(0x01ul<<2),
	STC16_CM1_Mode_Match	=	(0x00ul<<2)
}STC16_CM1_Mode_TypeDef;
/******************************************************************************
******************** ST16 External Functions Declaration *********************
******************************************************************************/  
extern void STC16_RESET_VALUE(void);
extern void STC16_IO_Init(ST16_IO_MODE_TypeDef  STC16_IO_MODE_X , U8_T STC16_IO_G );
extern void STC16_Clk_CMD(FunctionalStatus NewState);
extern void STC16_Softreset(void);
extern void STC16_Start(void);
extern void STC16_stop(void);
extern void STC16_Channel0_CMD(FunctionalStatus NewState);
extern void STC16_Channel1_CMD(FunctionalStatus NewState);
extern void STC16_MINT_CMD(STC16_MINT_TypeDef STC16_MINT_X , FunctionalStatus NewState);
extern void STC16_CINT_CMD(STC16_CINT_TypeDef STC16_CINT_X , FunctionalStatus NewState);
extern void STC16_Configure(STC16_Count_mode_TypeDef STC16_Count_mode_X , STC16_Count_STOPTYPE_TypeDef STC16_Count_STOPTYPE
					 , STC16_CM0_Mode_TypeDef STC16_CM0_Mode_X , STC16_CM1_Mode_TypeDef STC16_CM1_Mode_X , int STC16_DIVM , int STC16_DIVN);
extern void STC16_Channel0_Capture_LoadMode_set(STC16_C0SR_TypeDef STC16_C0SR_X);
extern void STC16_Channel1_Capture_LoadMode_set(STC16_C1SR_TypeDef STC16_C1SR_X);
extern void STC16_CNR_CC0_CC1_Load(U16_T STC16_CNTR, U16_T STC16_CC0R , U16_T STC16_CC1R);
extern void STC16_Int_Enable(void);
extern void STC16_Int_Disable(void);
extern void STC16_Wakeup_Enable(void);
extern void STC16_Wakeup_Disable(void);					 

#endif   /**< apt32f172_tc2_st16_H */

/******************* (C) COPYRIGHT 2018 APT Chip *****END OF FILE****/
